==> openshift-model-operatorhub-5.12.0-sources.jar: io/fabric8/openshift/api/model/operatorhub/v1alpha1/StepBuilder.java <==
package io.fabric8.openshift.api.model.operatorhub.v1alpha1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;
public class StepBuilder extends io.fabric8.openshift.api.model.operatorhub.v1alpha1.StepFluentImpl<io.fabric8.openshift.api.model.operatorhub.v1alpha1.StepBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<io.fabric8.openshift.api.model.operatorhub.v1alpha1.Step,io.fabric8.openshift.api.model.operatorhub.v1alpha1.StepBuilder>{
  public StepBuilder() {
    this(false);
  }
  public StepBuilder(java.lang.Boolean validationEnabled) {
    this(new Step(), validationEnabled);
  }
  public StepBuilder(io.fabric8.openshift.api.model.operatorhub.v1alpha1.StepFluent<?> fluent) {
    this(fluent, false);
  }
  public StepBuilder(io.fabric8.openshift.api.model.operatorhub.v1alpha1.StepFluent<?> fluent,java.lang.Boolean validationEnabled) {
    this(fluent, new Step(), validationEnabled);
  }
  public StepBuilder(io.fabric8.openshift.api.model.operatorhub.v1alpha1.StepFluent<?> fluent,io.fabric8.openshift.api.model.operatorhub.v1alpha1.Step instance) {
    this(fluent, instance, false);
  }
  public StepBuilder(io.fabric8.openshift.api.model.operatorhub.v1alpha1.StepFluent<?> fluent,io.fabric8.openshift.api.model.operatorhub.v1alpha1.Step instance,java.lang.Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withResolving(instance.getResolving()); 
    fluent.withResource(instance.getResource()); 
    fluent.withStatus(instance.getStatus()); 
    fluent.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  public StepBuilder(io.fabric8.openshift.api.model.operatorhub.v1alpha1.Step instance) {
    this(instance,false);
  }
  public StepBuilder(io.fabric8.openshift.api.model.operatorhub.v1alpha1.Step instance,java.lang.Boolean validationEnabled) {
    this.fluent = this; 
    this.withResolving(instance.getResolving()); 
    this.withResource(instance.getResource()); 
    this.withStatus(instance.getStatus()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  io.fabric8.openshift.api.model.operatorhub.v1alpha1.StepFluent<?> fluent;
  java.lang.Boolean validationEnabled;
  public io.fabric8.openshift.api.model.operatorhub.v1alpha1.Step build() {
    Step buildable = new Step(fluent.getResolving(),fluent.getResource(),fluent.getStatus());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    StepBuilder that = (StepBuilder) o;
    if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

    if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
  }
  
}

==> openshift-model-operatorhub-6.2.0-sources.jar: io/fabric8/openshift/api/model/operatorhub/v1alpha1/StepBuilder.java <==
package io.fabric8.openshift.api.model.operatorhub.v1alpha1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class StepBuilder extends StepFluentImpl<StepBuilder> implements VisitableBuilder<Step,StepBuilder>{
  public StepBuilder() {
    this(false);
  }
  public StepBuilder(Boolean validationEnabled) {
    this(new Step(), validationEnabled);
  }
  public StepBuilder(StepFluent<?> fluent) {
    this(fluent, false);
  }
  public StepBuilder(StepFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new Step(), validationEnabled);
  }
  public StepBuilder(StepFluent<?> fluent,Step instance) {
    this(fluent, instance, false);
  }
  public StepBuilder(StepFluent<?> fluent,Step instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withResolving(instance.getResolving()); 
    fluent.withResource(instance.getResource()); 
    fluent.withStatus(instance.getStatus()); 
    fluent.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  public StepBuilder(Step instance) {
    this(instance,false);
  }
  public StepBuilder(Step instance,Boolean validationEnabled) {
    this.fluent = this; 
    this.withResolving(instance.getResolving()); 
    this.withResource(instance.getResource()); 
    this.withStatus(instance.getStatus()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  StepFluent<?> fluent;
  Boolean validationEnabled;
  public Step build() {
    Step buildable = new Step(fluent.getResolving(),fluent.getResource(),fluent.getStatus());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  
}
